==> integral-mall-feign-airport-1.0.1-20250626.095651-4-sources.jar: com/bizvane/airport/mall/feign/model/req/IntegralMallOrderConfirmReceiptReq.java <==
package com.bizvane.airport.mall.feign.model.req;

import com.bizvane.utils.enumutils.IntegralMallOrderStatusOperationTypeEnum;
import com.bizvane.utils.validation.CreateValidation;
import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;
import lombok.Getter;
import lombok.Setter;
import org.apache.commons.lang3.StringUtils;

import javax.validation.constraints.AssertTrue;
import javax.validation.constraints.NotBlank;
import javax.validation.constraints.NotNull;
import java.io.Serializable;

/**
 * <p>
 * 积分商城订单
 * </p>
 *
 * @author bizvane
 * @since 2024-11-06
 */
@Getter
@Setter
@ApiModel(description = "积分商城订单收货")
public class IntegralMallOrderConfirmReceiptReq implements Serializable {

    private static final long serialVersionUID = 1L;

    @ApiModelProperty("系统编号")
    @NotBlank(message = "系统编号不能为空", groups = {CreateValidation.class})
    private String integralMallOrderCode;

    @ApiModelProperty("会员系统编号code")
    @NotBlank(message = "会员系统编号code不能为空", groups = {CreateValidation.class})
    private String mbrMemberCode;

    @ApiModelProperty("确认收货类型 1.用户确认收货 2.系统确认收货 3.后台确认收货")
    @NotNull(message = "确认收货类型不能为空", groups = {CreateValidation.class})
    private Integer confirmReceiptType;

    @ApiModelProperty("确认收货描述")
    @NotBlank(message = "确认收货描述不能为空", groups = {CreateValidation.class})
    private String confirmReceiptDesc;

    @ApiModelProperty("更新人code")
    private String modifiedUserCode;

    @ApiModelProperty("更新人姓名")
    private String modifiedUserName;

    @AssertTrue(message = "操作人信息不能为空", groups = {CreateValidation.class})
    public boolean checkModifiedUserOnlyUserCancel() {
        return IntegralMallOrderStatusOperationTypeEnum.USER_OPERATION.getType().equals(confirmReceiptType) ? StringUtils.isNotBlank(modifiedUserCode) && StringUtils.isNotBlank(modifiedUserName) : true;
    }
}

==> integral-mall-feign-airport-20241115.064028-12-sources.jar: com/bizvane/airport/mall/feign/model/req/IntegralMallOrderConfirmReceiptReq.java <==
package com.bizvane.airport.mall.feign.model.req;

import com.bizvane.utils.enumutils.IntegralMallOrderStatusOperationTypeEnum;
import com.bizvane.utils.validation.CreateValidation;
import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;
import lombok.Getter;
import lombok.Setter;
import org.apache.commons.lang3.StringUtils;

import javax.validation.constraints.AssertTrue;
import javax.validation.constraints.NotBlank;
import javax.validation.constraints.NotNull;
import java.io.Serializable;

/**
 * <p>
 * 积分商城订单
 * </p>
 *
 * @author bizvane
 * @since 2024-11-06
 */
@Getter
@Setter
@ApiModel(description = "积分商城订单收货")
public class IntegralMallOrderConfirmReceiptReq implements Serializable {

    private static final long serialVersionUID = 1L;

    @ApiModelProperty("系统编号")
    @NotBlank(message = "系统编号不能为空", groups = {CreateValidation.class})
    private String integralMallOrderCode;

    @ApiModelProperty("会员系统编号code")
    @NotBlank(message = "会员系统编号code不能为空", groups = {CreateValidation.class})
    private String mbrMemberCode;

    @ApiModelProperty("确认收货类型 1.用户确认收货 2.系统确认收货 3.后台确认收货")
    @NotNull(message = "取消类型不能为空", groups = {CreateValidation.class})
    private Integer confirmReceiptType;

    @ApiModelProperty("更新人code")
    private String modifiedUserCode;

    @ApiModelProperty("更新人姓名")
    private String modifiedUserName;

    @AssertTrue(message = "操作人信息不能为空", groups = {CreateValidation.class})
    public boolean checkModifiedUserOnlyUserCancel() {
        return IntegralMallOrderStatusOperationTypeEnum.USER_OPERATION.getType().equals(confirmReceiptType) && StringUtils.isNotBlank(modifiedUserCode) && StringUtils.isNotBlank(modifiedUserName);
    }
}
